@@ -88,7 +88,7 @@ formatting = {
     'speech': {
         'prefix': {
             'focused': '[]',
-            'unfocused': 'oldAncestors + newAncestors + newRowHeader + newColumnHeader + newRadioButtonGroup',
+            'unfocused': 'oldAncestors + newAncestors',
             'basicWhereAmI': 'toolbar',
             'detailedWhereAmI' : '[]'
             },
@@ -132,7 +132,7 @@ formatting = {
             'basicWhereAmI': 'label + roleName + value + percentage + ' + MNEMONIC + ' + accelerator + required'
             },
         pyatspi.ROLE_COMBO_BOX: {
-            'focused': 'name + positionInList',
+            'focused': 'name + roleName + positionInList',
             'unfocused': 'label + name + roleName + positionInList + ' + MNEMONIC + ' + accelerator',
             'basicWhereAmI': 'label + roleName + name + positionInList + ' + MNEMONIC + ' + accelerator'
             },
@@ -184,7 +184,7 @@ formatting = {
             'basicWhereAmI': 'linkInfo + siteDescription + fileSize + ' + MNEMONIC
             },
         pyatspi.ROLE_LIST: {
-            'focused': 'focusedItem',
+            'focused': 'labelOrName + multiselectableState + numberOfChildren',
             'unfocused': 'labelOrName + focusedItem + multiselectableState + numberOfChildren'
             },
         pyatspi.ROLE_LIST_ITEM: {
@@ -193,7 +193,7 @@ formatting = {
             'basicWhereAmI': 'label + roleName + name + positionInList + expandableState + (nodeLevel or nestingLevel)'
             },
         pyatspi.ROLE_MENU: {
-            'focused': '[]',
+            'focused': 'labelAndName + roleName',
             'unfocused': 'labelAndName + allTextSelection + roleName + availability + ' + MNEMONIC + ' + accelerator + positionInList',
             'basicWhereAmI': '(ancestors or parentRoleName) + labelAndName + roleName +  positionInList + ' + MNEMONIC
             },
@@ -210,6 +210,9 @@ formatting = {
             'unfocused': 'labelAndName + roleName + positionInList + ' + MNEMONIC + ' + accelerator',
             'basicWhereAmI': 'parentRoleName + labelAndName + roleName + positionInList + ' + MNEMONIC + ' + accelerator'
             },
+        pyatspi.ROLE_PANEL: {
+            'focused': 'labelAndName + roleName',
+            },
         pyatspi.ROLE_PARAGRAPH: {
             'focused': 'labelOrName + readOnly + textRole + currentLineText + allTextSelection',
             'unfocused': 'labelOrName + readOnly + textRole + currentLineText + allTextSelection + ' + MNEMONIC,
@@ -288,7 +291,7 @@ formatting = {
             'focused':   '(tableCell2ChildLabel + tableCell2ChildToggle)\
                           or (cellCheckedState + (expandableState and (expandableState + numberOfChildren)))',
             'unfocused': '(tableCell2ChildLabel + tableCell2ChildToggle)\
-                          or (columnHeaderIfToggleAndNoText\
+                          or (newRowHeader + (newColumnHeader or columnHeaderIfToggleAndNoText) \
                               + cellCheckedState\
                               + (realActiveDescendantDisplayedText or imageDescription + image)\
                               + (expandableState and (expandableState + numberOfChildren))\
@@ -452,27 +455,27 @@ formatting = {
             },
         pyatspi.ROLE_MENU: {
             'focused':   '[Component(obj,\
-                                     asString(label + displayedText + roleName + availability) + asString(accelerator))]',
+                                     asString(labelAndName + roleName + availability) + asString(accelerator))]',
             'unfocused': '[Component(obj,\
-                                     asString(label + displayedText + roleName))]',
+                                     asString(labelAndName + roleName))]',
             },
         #pyatspi.ROLE_MENU_BAR: 'default'
         pyatspi.ROLE_MENU_ITEM: {
             'unfocused': '[Component(obj,\
-                                     asString(label + displayedText + expandableState + availability) + asString(accelerator),\
+                                     asString(labelAndName + expandableState + availability) + asString(accelerator),\
                                      indicator=asString(menuItemCheckedState))]'
             },
         #pyatspi.ROLE_OPTION_PANE: 'default'
         pyatspi.ROLE_PAGE_TAB: {
             'focused':   '[Component(obj,\
-                                     asString(label + displayedText + roleName + availability) + asString(accelerator))]',
+                                     asString(labelAndName + roleName + availability) + asString(accelerator))]',
             'unfocused': '[Component(obj,\
-                                     asString(label + displayedText + roleName))]'
+                                     asString(labelAndName + roleName))]'
             },
         #pyatspi.ROLE_PAGE_TAB_LIST: 'default'
         pyatspi.ROLE_PANEL: {
             'unfocused': '[Component(obj,\
-                                     asString((label or displayedText) + roleName))]\
+                                     asString(labelAndName + roleName))]\
                           + (childWidget and ([Region(" ")] + childWidget))'
             },
         pyatspi.ROLE_PARAGRAPH: {
@@ -484,20 +487,20 @@ formatting = {
         #pyatspi.ROLE_PROGRESS_BAR: 'default'
         pyatspi.ROLE_PUSH_BUTTON: {
             'unfocused': '[Component(obj,\
-                                     asString(((label + displayedText) or description) + expandableState + roleName))]'
+                                     asString((labelAndName or description) + expandableState + roleName))]'
             },
         pyatspi.ROLE_RADIO_BUTTON: {
             'unfocused': '[Component(obj,\
-                                     asString(((label + displayedText) or description) + roleName),\
+                                     asString((labelAndName or description) + roleName),\
                                      indicator=asString(radioState))]'
             },
         pyatspi.ROLE_RADIO_MENU_ITEM: {
             'focused':   '[Component(obj,\
-                                     asString(((label + displayedText) or description) + roleName + availability)\
+                                     asString((labelAndName or description) + roleName + availability)\
                                      + asString(accelerator),\
                                      indicator=asString(radioState))]',
             'unfocused': '[Component(obj,\
-                                     asString((label + displayedText) or description)\
+                                     asString(labelAndName or description)\
                                      + asString(accelerator),\
                                      indicator=asString(radioState))]'
             },
@@ -546,7 +549,7 @@ formatting = {
             },
         pyatspi.ROLE_TOGGLE_BUTTON: {
             'unfocused': '[Component(obj,\
-                                     asString(((label + displayedText) or description) + expandableState + roleName),\
+                                     asString((labelAndName or description) + expandableState + roleName),\
                                      indicator=asString(toggleState))]'
             },
         #pyatspi.ROLE_TOOL_BAR: 'default'
