@@ -71,6 +71,7 @@ class Script(default.Script):
         default.Script.__init__(self, app)
         self._loadingDocumentContent = False
         self._isBrowser = isBrowser
+        self._lastCaretContext = None, -1
 
         self.sayAllOnLoadCheckButton = None
 
@@ -195,6 +196,8 @@ class Script(default.Script):
         - event: the Event
         """
 
+        self._lastCaretContext = event.source, event.detail1
+
         lastKey, mods = self.utilities.lastKeyAndModifiers()
         if lastKey in ['Tab', 'ISO_Left_Tab']:
             return
@@ -213,13 +216,15 @@ class Script(default.Script):
     def onDocumentReload(self, event):
         """Callback for document:reload accessibility events."""
 
-        if event.source.getRole() == pyatspi.ROLE_DOCUMENT_FRAME:
+        docRoles = [pyatspi.ROLE_DOCUMENT_FRAME, pyatspi.ROLE_DOCUMENT_WEB]
+        if event.source.getRole() in docRoles:
             self._loadingDocumentContent = True
 
     def onDocumentLoadComplete(self, event):
         """Callback for document:load-complete accessibility events."""
 
-        if event.source.getRole() != pyatspi.ROLE_DOCUMENT_FRAME:
+        docRoles = [pyatspi.ROLE_DOCUMENT_FRAME, pyatspi.ROLE_DOCUMENT_WEB]
+        if not event.source.getRole() in docRoles:
             return
 
         self._loadingDocumentContent = False
@@ -240,7 +245,8 @@ class Script(default.Script):
     def onDocumentLoadStopped(self, event):
         """Callback for document:load-stopped accessibility events."""
 
-        if event.source.getRole() == pyatspi.ROLE_DOCUMENT_FRAME:
+        docRoles = [pyatspi.ROLE_DOCUMENT_FRAME, pyatspi.ROLE_DOCUMENT_WEB]
+        if event.source.getRole() in docRoles:
             self._loadingDocumentContent = False
 
     def onFocusedChanged(self, event):
@@ -248,6 +254,8 @@ class Script(default.Script):
 
         obj = event.source
         role = obj.getRole()
+        self._lastCaretContext = obj, -1
+
         if role == pyatspi.ROLE_LIST_ITEM and obj.childCount:
             return
 
@@ -284,7 +292,8 @@ class Script(default.Script):
         except:
             return
 
-        if role != pyatspi.ROLE_DOCUMENT_FRAME or not self._isBrowser:
+        docRoles = [pyatspi.ROLE_DOCUMENT_FRAME, pyatspi.ROLE_DOCUMENT_WEB]
+        if role not in docRoles or not self._isBrowser:
             return
 
         if event.detail1:
@@ -448,6 +457,8 @@ class Script(default.Script):
         """
 
         def implementsText(obj):
+            if obj.getRole() == pyatspi.ROLE_LIST:
+                return False
             return 'Text' in utils.listInterfaces(obj)
 
         child = obj
@@ -564,8 +575,8 @@ class Script(default.Script):
         if obj.getRole() == pyatspi.ROLE_LINK:
             obj = obj.parent
 
-        document = utils.findAncestor(
-            obj, lambda x: x.getRole() == pyatspi.ROLE_DOCUMENT_FRAME)
+        docRoles = [pyatspi.ROLE_DOCUMENT_FRAME, pyatspi.ROLE_DOCUMENT_WEB]
+        document = utils.findAncestor(obj, lambda x: x.getRole() in docRoles)
         if not document or document.getState().contains(pyatspi.STATE_BUSY):
             return
 
