@@ -257,7 +257,9 @@ class SpeechGenerator(generator.Generator):
         acss = self.voice(SYSTEM)
         role = args.get('role', obj.getRole())
 
-        doNotPresent = [pyatspi.ROLE_UNKNOWN, pyatspi.ROLE_FILLER]
+        doNotPresent = [pyatspi.ROLE_UNKNOWN,
+                        pyatspi.ROLE_FILLER,
+                        pyatspi.ROLE_EXTENDED]
 
         # egg-list-box, e.g. privacy panel in gnome-control-center
         if obj.parent and obj.parent.getRole() == pyatspi.ROLE_LIST_BOX:
@@ -1485,13 +1487,18 @@ class SpeechGenerator(generator.Generator):
             if role == pyatspi.ROLE_COMBO_BOX:
                 return []
 
+        skipRoles = args.get('skipRoles', [])
+        stopAtRoles = args.get('stopAtRoles', [])
+        stopAtRoles.append(pyatspi.ROLE_APPLICATION)
         if obj != commonAncestor:
             parent = obj.parent
             while parent and not parent in [commonAncestor, parent.parent]:
-                if parent.getRole() == pyatspi.ROLE_APPLICATION:
+                parentRole = parent.getRole()
+                if parentRole in stopAtRoles:
                     break
-                if not self._script.utilities.isLayoutOnly(parent):
-                    result.append(self.generate(parent))
+                if parentRole not in skipRoles \
+                   and not self._script.utilities.isLayoutOnly(parent):
+                    result.append(self.generate(parent, formatType='focused'))
                 parent = parent.parent
         result.reverse()
         return result
